@@ -3,7 +3,7 @@ use Carp;
 use strict;
 use Class::ISA;
 
-$CGI::Application::VERSION = '4.02_1';
+$CGI::Application::VERSION = '4.04_01';
 
 my %INSTALLED_CALLBACKS = (
 #	hook name          package                 sub
@@ -32,6 +32,15 @@ sub new {
 	my $self = {};
 	bless($self, $class);
 
+    ### SET UP DEFAULT VALUES ###
+    #
+    # We set them up here and not in the setup() because a subclass
+    # which implements setup() still needs default values!
+
+    $self->header_type('header');
+    $self->mode_param('rm');
+    $self->start_mode('start');
+
 	# Process optional new() parameters
 	my $rprops;
 	if (ref($args[0]) eq 'HASH') {
@@ -68,15 +77,6 @@ sub new {
 	# down the line.
 	$self->call_hook('init', @args);
 
-	### SET UP DEFAULT VALUES ###
-	#
-	# We set them up here and not in the setup() because a subclass
-	# which implements setup() still needs default values!
-
-	$self->header_type('header');
-	$self->mode_param('rm');
-	$self->start_mode('start') unless defined $self->start_mode;
-
 	# Call setup() method, which should be implemented in the sub-class!
 	$self->setup();
 
@@ -965,7 +965,8 @@ as a run mode, passing $@ as the only parameter.
 
 Plugins authors will be interested to know that just before C<error_mode()> is
 called, the C<error> hook will be executed, with the error message passed in as
-the only parameter.
+the only parameter. This hook is still considered experimental, although it is
+unlikely to change.
 
 For a complete integrated logging solution, check out L<CGI::Application::Plugin::LogDispatch>.
 
@@ -1323,10 +1324,19 @@ header_type() to "none".  This will completely hide headers.
 
 =item load_tmpl()
 
-    my $tmpl_obj = $webapp->load_tmpl('some.tmpl');
+    my $tmpl_obj = $webapp->load_tmpl;
+    my $tmpl_obj = $webapp->load_tmpl('some.html');
 
 This method takes the name of a template file and returns an
-HTML::Template object.  ( For integration with other template systems
+HTML::Template object. If the filename is undefined or missing,  
+CGI::Application will default to trying to use the current run mode name,
+plus the extension ".html". 
+
+If you use the default template naming system, you should also use
+L<CGI::Application::Plugin::Forward>, which simply helps to keep the current
+name accurate when you pass control from one run mode to another.
+
+( For integration with other template systems
 and automated template names, see "Alternatives to load_tmpl() below. )
 
 The HTML::Template->new_file() constructor is used for create the object.
@@ -1340,7 +1350,15 @@ The load_tmpl() method will pass any extra parameters sent to it directly to
 HTML::Template->new_file().  This will allow the HTML::Template object to be
 further customized:
 
-    my $tmpl_obj = $webapp->load_tmpl('some_other.tmpl',
+    my $tmpl_obj = $webapp->load_tmpl('some_other.html',
+         die_on_bad_params => 0,
+         cache => 1
+    );
+
+Note that if you want to pass extra arguments but use the default template
+name, you still need to provide a name of C<undef>:
+
+    my $tmpl_obj = $webapp->load_tmpl(undef',
          die_on_bad_params => 0,
          cache => 1
     );
@@ -1411,8 +1429,17 @@ sub load_tmpl {
 		push(@extra_params, path => [ @tmpl_paths ]) unless $found;
 	}
 
-    my %tmpl_params;
+    my %tmpl_params = ();
     my %ht_params = @extra_params;
+    %ht_params = () unless keys %ht_params;
+
+    # Define our extension if doesn't already exist;
+    $self->{__CURRENT_TMPL_EXTENSION} = '.html' unless defined $self->{__CURRENT_TMPL_EXTENSION};
+
+    # Define a default templat name based on the current run mode
+    unless (defined $tmpl_file) {
+        $tmpl_file = $self->get_current_runmode . $self->{__CURRENT_TMPL_EXTENSION};    
+    }
 
     $self->call_hook('load_tmpl', \%ht_params, \%tmpl_params, $tmpl_file);
 
@@ -1882,6 +1909,10 @@ L<CGI::Application::Plugin::DBH> - Integration with L<DBI>.
 
 =item *
 
+L<CGI::Application::Plugin::FillInForm> - Integration with L<HTML::FillInForm>.
+
+=item *
+
 L<CGI::Application::Plugin::LogDispatch> - Integration with L<Log::Dispatch>
 
 =item *
@@ -2130,6 +2161,7 @@ sub call_hook {
 			die "Error executing class callback in $hook stage: $@" if $@;
 		}
 	}
+
 }
 
 =pod
